==> media-downloader-dmo_1.7.0.orig.tar.gz: media-downloader-1.7.0/src/engines/gallery-dl.h <==
/*
 *
 *  Copyright (c) 2021
 *  name : Francis Banyikwa
 *  email: mhogomchungu@gmail.com
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QByteArray>

#include "../engines.h"

class settings ;

class gallery_dl : public engines::engine::functions
{
public:
	~gallery_dl() override ;
	gallery_dl( const engines&,const engines::engine&,QJsonObject& ) ;

	class gallery_dlFilter : public engines::engine::functions::filter
	{
	public:
		gallery_dlFilter( const QString&,settings&,const engines::engine& ) ;

		const QString& operator()( const Logger::Data& e ) override ;

		virtual ~gallery_dlFilter() override ;
	private:
		QString m_tmp ;
	} ;

	engines::engine::functions::DataFilter Filter( const QString& ) override ;

	void runCommandOnDownloadedFile( const QString&,const QString& ) override ;

	QString updateTextOnCompleteDownlod( const QString& uiText,
					     const QString& bkText,
					     const engines::engine::functions::finishedState& ) override ;

	void updateDownLoadCmdOptions( const engines::engine::functions::updateOpts& ) override ;
private:
	const engines& m_engines ;
};

==> media-downloader-dmo_2.1.1.orig.tar.gz: media-downloader-2.1.1/src/engines/gallery-dl.h <==
/*
 *
 *  Copyright (c) 2021
 *  name : Francis Banyikwa
 *  email: mhogomchungu@gmail.com
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QByteArray>

#include "../engines.h"

class settings ;

class gallery_dl : public engines::engine::functions
{
public:
	~gallery_dl() override ;
	gallery_dl( const engines&,const engines::engine&,QJsonObject& ) ;

	class gallery_dlFilter : public engines::engine::functions::filter
	{
	public:
		gallery_dlFilter( const QString&,settings&,const engines::engine& ) ;

		const QByteArray& operator()( const Logger::Data& e ) override ;

		~gallery_dlFilter() override ;
	private:
		QByteArray m_tmp ;
	} ;

	engines::engine::functions::DataFilter Filter( const QString& ) override ;

	void runCommandOnDownloadedFile( const QString&,const QString& ) override ;

	QString updateTextOnCompleteDownlod( const QString& uiText,
					     const QString& bkText,
					     const QString& downloadingOptions,
					     const engines::engine::functions::finishedState& ) override ;

	void updateDownLoadCmdOptions( const engines::engine::functions::updateOpts& ) override ;
private:
};
